# PIEC
 Python Integrated Experimental Control
 The goal of this repository is to provide a streamlined control scheme for lab experiments and allow for rapid development
 of new experimental procedures starting from a ferroelectric standpoint.
 Requires KEYSIGHT I/O Libraries, find them here: www.keysight.com/find/iosuite
probably not needed:
 https://www.keysight.com/us/en/lib/software-detail/computer-software/visa-shared-components-downloads-2504667.html download this first?
This is needed!
 https://www.ni.com/en/support/downloads/drivers/download.ni-488-2.html#544048


Overall how to install:
1. ```pip install piec```
2. Install NI 488.2 Drivers if using GPIB




NOTE: If using the digilent driver:
Make sure you Install InstaCal and the Universal Library (UL) from http://www.mccdaq.com/swdownload 
Note InstaCal is actually not needed but useful to troubleshoot if python is not working
Also mcculw library is needed. it is NOT in the required dependencies (subject to change)

[![Documentation Status](https://readthedocs.org/projects/piec/badge/?version=latest)](https://piec.readthedocs.io/en/latest/?badge=latest)

